%global srcname pymoc
%global sum Multi-Order Coverage map module for Python
%global desc PyMOC is a module for manipulating Multi-Order Coverage (MOC) maps. \
It includes support for reading and writing the three encodings mentioned in     \
the IVOA recommendation: FITS, JSON and ASCII.                                   \
                                                                                 \
PyMOC also includes a utility program pymoctool to allow MOC files to be         \
manipulated from the command line.

# Is a noarch package in reality, see below, therefore: no debuginfo
%global debug_package %{nil}


Name:           python-%{srcname}
Version:        0.5.0
Release:        2%{?dist}
Summary:        %{sum}

License:        GPLv3+
URL:            https://pypi.python.org/pypi/%{srcname}
Source0:        https://files.pythonhosted.org/packages/source/p/%{srcname}/%{srcname}-%{version}.tar.gz

# Cannot build as noarch because healpy does not support 32 bit architectures
# and we need that to execute tests. At runtime healpy is optional though,
# thereforce subpackages are noarch
ExclusiveArch:  aarch64 ppc64 ppc64le x86_64 s390x
# Also explicitly exclude known unsupported architectures
ExcludeArch:    %{ix86} %{arm}

# Python2
BuildRequires:  python2-astropy
BuildRequires:  python2-devel
BuildRequires:  python2-healpy
BuildRequires:  python2-pytest
BuildRequires:  python2-setuptools
# Python3
BuildRequires:  python3-astropy
BuildRequires:  python3-devel
BuildRequires:  python3-healpy
BuildRequires:  python3-pytest
BuildRequires:  python3-setuptools
%description
%{desc}

%package -n python2-%{srcname}
Summary:        %{sum}
BuildArch:      noarch
Requires:       python2-astropy
Recommends:     python2-healpy
%{?python_provide:%python_provide python2-%{srcname}}

%description -n python2-%{srcname}
%{desc}


%package -n python3-%{srcname}
Summary:        %{sum}
BuildArch:      noarch
Requires:       python3-astropy
Recommends:     python3-healpy
%{?python_provide:%python_provide python3-%{srcname}}

%description -n python3-%{srcname}
%{desc}


%prep
%autosetup -n %{srcname}-%{version}


%build
%py2_build
%py3_build


%install
# Must do the python2 install first because the scripts in /usr/bin are
# overwritten with every setup.py install, and in general we want the
# python3 version to be the default.
%py2_install
%py3_install


%check
PYTHONPATH=%{buildroot}%{python2_sitelib} %{__python2} -m unittest discover
PYTHONPATH=%{buildroot}%{python3_sitelib} %{__python3} -m unittest discover


# Note that there is no %%files section for the unversioned python module if we are building for several python runtimes
%files -n python2-%{srcname}
%license COPYING
%doc README.rst
%{python2_sitelib}/*

%files -n python3-%{srcname}
%license COPYING
%doc README.rst
%{python3_sitelib}/*
%{_bindir}/pymoctool

%changelog
* Thu Jun 01 2017 Christian Dersch <lupinix@mailbox.org> - 0.5.0-2
- have to make the package ExclusiveArch limited to healpy arches (to run tests)

* Thu Jun 01 2017 Christian Dersch <lupinix@mailbox.org> - 0.5.0-1
- new version

* Thu Apr 20 2017 Christian Dersch <lupinix@mailbox.org> - 0.4.2-1
- initial package

